aboutsummaryrefslogtreecommitdiff
path: root/ML_ADM
diff options
context:
space:
mode:
authorErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
committerErik Schnetter <schnetter@cct.lsu.edu>2009-11-14 21:37:05 -0600
commitd178c81a0cb1da927bfd7d0bb64043d9484b353b (patch)
tree2a48ab29ef4a72dc1d1ae60e00cd7c0f231ae823 /ML_ADM
parent87fa6dcf3ff19d937313d20cca8f9e2bca1d4aec (diff)
Allow 4 RHS time levels.
Re-generate code.
Diffstat (limited to 'ML_ADM')
-rw-r--r--ML_ADM/schedule.ccl6
-rw-r--r--ML_ADM/src/Boundaries.c82
2 files changed, 44 insertions, 44 deletions
diff --git a/ML_ADM/schedule.ccl b/ML_ADM/schedule.ccl
index 0140a0d..6e7faee 100644
--- a/ML_ADM/schedule.ccl
+++ b/ML_ADM/schedule.ccl
@@ -187,7 +187,7 @@ schedule ML_ADM_constraints_boundary AT analysis AFTER ML_ADM_constraints
LANG: C
} "ML_ADM_constraints_boundary"
-schedule ML_ADM_ApplyBoundConds in MoL_PostStep
+schedule ML_ADM_SelectBoundConds in MoL_PostStep
{
LANG: C
OPTIONS: level
@@ -195,7 +195,7 @@ schedule ML_ADM_ApplyBoundConds in MoL_PostStep
SYNC: ML_lapse
SYNC: ML_metric
SYNC: ML_shift
-} "apply boundary conditions"
+} "select boundary conditions"
schedule ML_ADM_CheckBoundaries at BASEGRID
{
@@ -203,7 +203,7 @@ schedule ML_ADM_CheckBoundaries at BASEGRID
OPTIONS: meta
} "check boundaries treatment"
-schedule group ApplyBCs as ML_ADM_ApplyBCs in MoL_PostStep after ML_ADM_ApplyBoundConds
+schedule group ApplyBCs as ML_ADM_ApplyBCs in MoL_PostStep after ML_ADM_SelectBoundConds
{
# no language specified
} "Apply boundary conditions controlled by thorn Boundary"
diff --git a/ML_ADM/src/Boundaries.c b/ML_ADM/src/Boundaries.c
index bb27ba6..f8b547f 100644
--- a/ML_ADM/src/Boundaries.c
+++ b/ML_ADM/src/Boundaries.c
@@ -25,7 +25,7 @@ void ML_ADM_CheckBoundaries(CCTK_ARGUMENTS)
return;
}
-void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
+void ML_ADM_SelectBoundConds(CCTK_ARGUMENTS)
{
DECLARE_CCTK_ARGUMENTS;
DECLARE_CCTK_PARAMETERS;
@@ -254,7 +254,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_curv_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ML_curv_bound = -1;
if (handle_ML_curv_bound < 0) handle_ML_curv_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_curv_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -273,7 +273,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_lapse_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ML_lapse_bound = -1;
if (handle_ML_lapse_bound < 0) handle_ML_lapse_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_lapse_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -292,7 +292,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_metric_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ML_metric_bound = -1;
if (handle_ML_metric_bound < 0) handle_ML_metric_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_metric_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -311,7 +311,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_shift_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_ML_shift_bound = -1;
if (handle_ML_shift_bound < 0) handle_ML_shift_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_shift_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -330,7 +330,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K11_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K11_bound = -1;
if (handle_K11_bound < 0) handle_K11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K11_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -349,7 +349,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K12_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K12_bound = -1;
if (handle_K12_bound < 0) handle_K12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K12_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -368,7 +368,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K13_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K13_bound = -1;
if (handle_K13_bound < 0) handle_K13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K13_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -387,7 +387,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K22_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K22_bound = -1;
if (handle_K22_bound < 0) handle_K22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K22_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -406,7 +406,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K23_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K23_bound = -1;
if (handle_K23_bound < 0) handle_K23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K23_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -425,7 +425,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K33_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_K33_bound = -1;
if (handle_K33_bound < 0) handle_K33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K33_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -444,7 +444,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(alpha_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_alpha_bound = -1;
if (handle_alpha_bound < 0) handle_alpha_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_alpha_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -463,7 +463,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g11_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g11_bound = -1;
if (handle_g11_bound < 0) handle_g11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g11_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -482,7 +482,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g12_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g12_bound = -1;
if (handle_g12_bound < 0) handle_g12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g12_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -501,7 +501,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g13_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g13_bound = -1;
if (handle_g13_bound < 0) handle_g13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g13_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -520,7 +520,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g22_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g22_bound = -1;
if (handle_g22_bound < 0) handle_g22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g22_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -539,7 +539,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g23_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g23_bound = -1;
if (handle_g23_bound < 0) handle_g23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g23_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -558,7 +558,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g33_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_g33_bound = -1;
if (handle_g33_bound < 0) handle_g33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g33_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -577,7 +577,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta1_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_beta1_bound = -1;
if (handle_beta1_bound < 0) handle_beta1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -596,7 +596,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta2_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_beta2_bound = -1;
if (handle_beta2_bound < 0) handle_beta2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -615,7 +615,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta3_bound, "radiative"))
{
/* apply radiation boundary condition */
static CCTK_INT handle_beta3_bound = -1;
if (handle_beta3_bound < 0) handle_beta3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -634,7 +634,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_curv_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ML_curv_bound = -1;
if (handle_ML_curv_bound < 0) handle_ML_curv_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_curv_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -651,7 +651,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_lapse_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ML_lapse_bound = -1;
if (handle_ML_lapse_bound < 0) handle_ML_lapse_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_lapse_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -668,7 +668,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_metric_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ML_metric_bound = -1;
if (handle_ML_metric_bound < 0) handle_ML_metric_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_metric_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -685,7 +685,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_shift_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_ML_shift_bound = -1;
if (handle_ML_shift_bound < 0) handle_ML_shift_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_ML_shift_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -702,7 +702,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K11_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K11_bound = -1;
if (handle_K11_bound < 0) handle_K11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K11_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -719,7 +719,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K12_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K12_bound = -1;
if (handle_K12_bound < 0) handle_K12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K12_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -736,7 +736,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K13_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K13_bound = -1;
if (handle_K13_bound < 0) handle_K13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K13_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -753,7 +753,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K22_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K22_bound = -1;
if (handle_K22_bound < 0) handle_K22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K22_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -770,7 +770,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K23_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K23_bound = -1;
if (handle_K23_bound < 0) handle_K23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K23_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -787,7 +787,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K33_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_K33_bound = -1;
if (handle_K33_bound < 0) handle_K33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_K33_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -804,7 +804,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(alpha_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_alpha_bound = -1;
if (handle_alpha_bound < 0) handle_alpha_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_alpha_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -821,7 +821,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g11_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g11_bound = -1;
if (handle_g11_bound < 0) handle_g11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g11_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -838,7 +838,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g12_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g12_bound = -1;
if (handle_g12_bound < 0) handle_g12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g12_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -855,7 +855,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g13_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g13_bound = -1;
if (handle_g13_bound < 0) handle_g13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g13_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -872,7 +872,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g22_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g22_bound = -1;
if (handle_g22_bound < 0) handle_g22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g22_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -889,7 +889,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g23_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g23_bound = -1;
if (handle_g23_bound < 0) handle_g23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g23_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -906,7 +906,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g33_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_g33_bound = -1;
if (handle_g33_bound < 0) handle_g33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_g33_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -923,7 +923,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta1_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_beta1_bound = -1;
if (handle_beta1_bound < 0) handle_beta1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta1_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -940,7 +940,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta2_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_beta2_bound = -1;
if (handle_beta2_bound < 0) handle_beta2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta2_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -957,7 +957,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta3_bound, "scalar"))
{
/* apply scalar boundary condition */
static CCTK_INT handle_beta3_bound = -1;
if (handle_beta3_bound < 0) handle_beta3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
if (handle_beta3_bound < 0) CCTK_WARN(0, "could not create table!");
@@ -254,7 +254,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_curv_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ML_curv_bound = -1;
if (handle_ML_curv_bound < 0) handle_ML_curv_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -273,7 +273,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_lapse_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ML_lapse_bound = -1;
if (handle_ML_lapse_bound < 0) handle_ML_lapse_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -292,7 +292,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_metric_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ML_metric_bound = -1;
if (handle_ML_metric_bound < 0) handle_ML_metric_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -311,7 +311,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_shift_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_ML_shift_bound = -1;
if (handle_ML_shift_bound < 0) handle_ML_shift_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -330,7 +330,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K11_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K11_bound = -1;
if (handle_K11_bound < 0) handle_K11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -349,7 +349,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K12_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K12_bound = -1;
if (handle_K12_bound < 0) handle_K12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -368,7 +368,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K13_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K13_bound = -1;
if (handle_K13_bound < 0) handle_K13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -387,7 +387,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K22_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K22_bound = -1;
if (handle_K22_bound < 0) handle_K22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -406,7 +406,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K23_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K23_bound = -1;
if (handle_K23_bound < 0) handle_K23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -425,7 +425,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K33_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_K33_bound = -1;
if (handle_K33_bound < 0) handle_K33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -444,7 +444,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(alpha_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_alpha_bound = -1;
if (handle_alpha_bound < 0) handle_alpha_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -463,7 +463,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g11_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g11_bound = -1;
if (handle_g11_bound < 0) handle_g11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -482,7 +482,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g12_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g12_bound = -1;
if (handle_g12_bound < 0) handle_g12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -501,7 +501,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g13_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g13_bound = -1;
if (handle_g13_bound < 0) handle_g13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -520,7 +520,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g22_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g22_bound = -1;
if (handle_g22_bound < 0) handle_g22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -539,7 +539,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g23_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g23_bound = -1;
if (handle_g23_bound < 0) handle_g23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -558,7 +558,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g33_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_g33_bound = -1;
if (handle_g33_bound < 0) handle_g33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -577,7 +577,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta1_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_beta1_bound = -1;
if (handle_beta1_bound < 0) handle_beta1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -596,7 +596,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta2_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_beta2_bound = -1;
if (handle_beta2_bound < 0) handle_beta2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -615,7 +615,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta3_bound, "radiative"))
{
- /* apply radiation boundary condition */
+ /* select radiation boundary condition */
static CCTK_INT handle_beta3_bound = -1;
if (handle_beta3_bound < 0) handle_beta3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -634,7 +634,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_curv_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ML_curv_bound = -1;
if (handle_ML_curv_bound < 0) handle_ML_curv_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -651,7 +651,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_lapse_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ML_lapse_bound = -1;
if (handle_ML_lapse_bound < 0) handle_ML_lapse_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -668,7 +668,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_metric_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ML_metric_bound = -1;
if (handle_ML_metric_bound < 0) handle_ML_metric_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -685,7 +685,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(ML_shift_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_ML_shift_bound = -1;
if (handle_ML_shift_bound < 0) handle_ML_shift_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -702,7 +702,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K11_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K11_bound = -1;
if (handle_K11_bound < 0) handle_K11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -719,7 +719,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K12_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K12_bound = -1;
if (handle_K12_bound < 0) handle_K12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -736,7 +736,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K13_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K13_bound = -1;
if (handle_K13_bound < 0) handle_K13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -753,7 +753,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K22_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K22_bound = -1;
if (handle_K22_bound < 0) handle_K22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -770,7 +770,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K23_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K23_bound = -1;
if (handle_K23_bound < 0) handle_K23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -787,7 +787,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(K33_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_K33_bound = -1;
if (handle_K33_bound < 0) handle_K33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -804,7 +804,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(alpha_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_alpha_bound = -1;
if (handle_alpha_bound < 0) handle_alpha_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -821,7 +821,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g11_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g11_bound = -1;
if (handle_g11_bound < 0) handle_g11_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -838,7 +838,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g12_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g12_bound = -1;
if (handle_g12_bound < 0) handle_g12_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -855,7 +855,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g13_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g13_bound = -1;
if (handle_g13_bound < 0) handle_g13_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -872,7 +872,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g22_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g22_bound = -1;
if (handle_g22_bound < 0) handle_g22_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -889,7 +889,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g23_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g23_bound = -1;
if (handle_g23_bound < 0) handle_g23_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -906,7 +906,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(g33_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_g33_bound = -1;
if (handle_g33_bound < 0) handle_g33_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -923,7 +923,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta1_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_beta1_bound = -1;
if (handle_beta1_bound < 0) handle_beta1_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -940,7 +940,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta2_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_beta2_bound = -1;
if (handle_beta2_bound < 0) handle_beta2_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);
@@ -957,7 +957,7 @@ void ML_ADM_ApplyBoundConds(CCTK_ARGUMENTS)
if (CCTK_EQUALS(beta3_bound, "scalar"))
{
- /* apply scalar boundary condition */
+ /* select scalar boundary condition */
static CCTK_INT handle_beta3_bound = -1;
if (handle_beta3_bound < 0) handle_beta3_bound = Util_TableCreate(UTIL_TABLE_FLAGS_CASE_INSENSITIVE);